@@ -397,10 +397,11 @@ class VirtualService(HttpClient, KempBaseObjectModel):
             response = self._get("/addvs", self._get_base_parameters())
         else:
             response = self._get("/modvs", self.to_api_dict())
-        send_response(response)
+        return send_response(response)
 
     def delete(self):
-        self._get("/delvs", self._get_base_parameters())
+        response = self._get("/delvs", self._get_base_parameters())
+        return send_response(response)
 
     def create_real_server(self, ip, port=80):
         """RealServer factory with pre-configured LoadMaster connection."""
@@ -499,8 +500,8 @@ class RealServer(HttpClient, KempBaseObjectModel):
             response = self._get("/addrs", self._get_base_parameters())
         else:
             response = self._get("/modrs", self.to_api_dict())
-        send_response(response)
+        return send_response(response)
 
     def delete(self):
         response = self._get("/delrs", self._get_base_parameters())
-        send_response(response)
+        return send_response(response)
