@@ -11,6 +11,7 @@ except ImportError:
 patch = mock.patch
 
 import python_kemptech_api.client as client
+from python_kemptech_api.client import LoadMaster, VirtualService
 import python_kemptech_api.exceptions as exceptions
 
 
@@ -90,3 +91,12 @@ class Test_set_parameter:
         self.is_successful.return_value = False
         with assert_raises(exceptions.LoadMasterParameterError):
             self.lm.set_parameter('a', 'b')
+
+
+class Test_virtual_service_crud:
+    def setup(self):
+        self.lm = LoadMaster("1.1.1.1", "bal", "2fourall")
+
+    def test_create_virtual_service_factory(self):
+        vs = self.lm.create_virtual_service("1.1.1.2", 90, "tcp")
+        assert_equal(isinstance(vs, VirtualService), True)
